#if defined(_MSC_VER) && !defined(_XBOX)
/* https://support.microsoft.com/en-us/kb/980263 */
#pragma execution_character_set("utf-8")
#endif

MSG_HASH(
      MSG_COMPILER,
      "コンパイラ"
      )
MSG_HASH(
      MSG_UNKNOWN_COMPILER,
      "不明なコンパイラ"
      )
MSG_HASH(
      MSG_DEVICE_DISCONNECTED_FROM_PORT,
      "Device disconnected from port"
      )
MSG_HASH(
      MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
      "不正なネットプレイコマンドが受信されました。"
      )
MSG_HASH(
      MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
      "File already exists. Saving to backup buffer"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM,
      "「%s」からの接続が確立しますた。"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM_NAME,
      "「%s (%s)」からの接続が確立しますた。"
      )
MSG_HASH(
      MSG_PUBLIC_ADDRESS,
      "公式IPアドレス"
      )
MSG_HASH(
      MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
      "No arguments supplied and no menu builtin, displaying help..."
      )
MSG_HASH(
      MSG_SETTING_DISK_IN_TRAY,
      "ディスクがトレイに入りました。"
      )
MSG_HASH(
      MSG_WAITING_FOR_CLIENT,
      "クライアントに待機中"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_LEFT_THE_GAME,
      "ゲームから退出しました"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_AS_PLAYER_N,
      "「プレイヤー%u」で接続しました"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_WITH_INPUT_DEVICES_S,
      "入力デバイス「%.*s」で接続しました"
      )
MSG_HASH(
      MSG_NETPLAY_PLAYER_S_LEFT,
      "プレヤー「%.*s」が退出しました"
      )
MSG_HASH(
      MSG_NETPLAY_S_HAS_JOINED_AS_PLAYER_N,
      "「%.*s」がプレヤー「%u」で接続しました"
      )
MSG_HASH(
      MSG_NETPLAY_S_HAS_JOINED_WITH_INPUT_DEVICES_S,
      "「%.*s」が入力デバイス「%.*s」で接続しました"
      )
MSG_HASH(
      MSG_NETPLAY_NOT_RETROARCH,
      "相手の接続が失敗しました。古いRetroArchバージョンを使っているかもしれません。"
      )
MSG_HASH(
      MSG_NETPLAY_OUT_OF_DATE,
      "相手のRetroArchバージョンは古いから接続できません。"
      )
MSG_HASH(
      MSG_NETPLAY_DIFFERENT_VERSIONS,
      "警告：相手が違うRetroArchバージョンを使っています。問題があれば同じバージョンを使って下さい。"
      )
MSG_HASH(
      MSG_NETPLAY_DIFFERENT_CORES,
      "相手が違うコアを使っています。接続できません。"
      )
MSG_HASH(
      MSG_NETPLAY_DIFFERENT_CORE_VERSIONS,
      "警告：相手が違うコアのバージョンを使っています。問題があれば同じバージョンを使って下さい。"
      )
MSG_HASH(
      MSG_NETPLAY_ENDIAN_DEPENDENT,
      "This core does not support inter-architecture netplay between these systems"
      )
MSG_HASH(
      MSG_NETPLAY_PLATFORM_DEPENDENT,
      "This core does not support inter-architecture netplay"
      )
MSG_HASH(
      MSG_NETPLAY_ENTER_PASSWORD,
      "ネットプレイサーバーのパスワードを入力してください:"
      )
MSG_HASH(
      MSG_NETPLAY_INCORRECT_PASSWORD,
      "不正なパスワード"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_NAMED_HANGUP,
      "「%s」は退出しました"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_HANGUP,
      "ネットプレイのクライアントが切断されました"
      )
MSG_HASH(
      MSG_NETPLAY_CLIENT_HANGUP,
      "ネットプレイが切断されました"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_UNPRIVILEGED,
      "プレイする許可はありません"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NO_SLOTS,
      "空きプレイヤースロットはありません"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NOT_AVAILABLE,
      "選択した入力デバイスが使えません。"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY,
      "プレイモードを切り替えに出来ませんでした"
      )
MSG_HASH(
      MSG_NETPLAY_PEER_PAUSED,
      "ネットプレイのピア「%s」が一時停止にしました"
      )
MSG_HASH(
      MSG_NETPLAY_CHANGED_NICK,
      "ニックネームは「%s」に設定しました"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
      "Give hardware-rendered cores their own private context. Avoids having to assume hardware state changes inbetween frames."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_SETTINGS,
      "メニューの外観関係の設定を変更する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
      "CPUとGPUを強制に同期する。遅延が減るけどパフォーマンスも減る。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_THREADED,
      "パフォーマンスを改良するけど、ビデオの遅延と途切れが増す。フルスピードを取得しない時だけで使用する。"
      )
MSG_HASH(
      MSG_AUDIO_VOLUME,
      "音量"
      )
MSG_HASH(
      MSG_AUTODETECT,
      "自動検出"
      )
MSG_HASH(
      MSG_AUTOLOADING_SAVESTATE_FROM,
      "Auto-loading savestate from"
      )
MSG_HASH(
      MSG_CAPABILITIES,
      "対応された機能"
      )
MSG_HASH(
      MSG_CONNECTING_TO_NETPLAY_HOST,
      "Connecting to netplay host"
      )
MSG_HASH(
      MSG_CONNECTING_TO_PORT,
      "Connecting to port"
      )
MSG_HASH(
      MSG_CONNECTION_SLOT,
      "Connection slot"
      )
MSG_HASH(
      MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
      "Sorry, unimplemented: cores that don't demand content cannot participate in netplay."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
      "パスワード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
      "Accounts Cheevos"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
      "ユーザー名"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
      "アカウント"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
      "Accounts List Endpoint"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "レトロ実績"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
      "実績表"
      )

MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
      "実績表(ハードコア)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
      "コンテンツをスキャン"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
      "設定ファイル"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_TAB,
      "コンテンツをインポート"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_NETPLAY_TAB,
      "ネットプレイのルーム表"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
      "Ask"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
      "資産"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
      "Block Frames"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
      "オーディオのデバイス"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
      "オーディオのドライバ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
      "オーディオのDSPプラグイン"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
      "オーディオを有効"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
      "オーディオフィルター"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
      "Turbo/Deadzone"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
      "オーディオの遅延 (ms)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
      "オーディオの最高タイミングスキュー"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
      "オーディオの消音"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
      "オーディオの出力レート(Hz)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
      "ダイナミックオーディオレートコントロール"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
      "オーディオリサンプラーのドライバ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
      "オーディオ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
      "オーディオの同期"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
      "オーディオの音量 (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_EXCLUSIVE_MODE,
      "WASAPIの排他モード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_FLOAT_FORMAT,
      "WASAPIの浮動小数点方式"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_WASAPI_SH_BUFFER_LENGTH,
      "WASAPIの共有バッファーサイズ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
      "セーブRAMの自動保存期間"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
      "オーバーライドファイルを自動的にロード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
      "リマップファイルを自動的にロード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
      "シェーダーのプリセットを自動的にロード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
      "戻る"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
      "確認"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
      "情報"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
      "終了"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
      "下にスクロール"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
      "上にスクロール"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
      "スタート"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
      "キーボードに切り替え"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
      "メニューに切り替え"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
      "基本的なメニューコントルール"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
      "確認/了承"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
      "情報"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
      "終了"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
      "上にスクロール"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
      "デフォルト"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
      "キーボードに切り替え"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
      "メニューに切り替え"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
      "保存状態をロード時にセーブRAMを置き換えない"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
      "Bluetoothを有効"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
      "Buildbotの資産URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
      "キャッシュ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
      "カメラを許す"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
      "カメラのドライバ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT,
      "チート";
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
      "チートの変更点を適用"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
      "チートファイル"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
      "チートファイル"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
      "チートファイルをロード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
      "チートファイルを名前を付けて保存"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INFORMATION,
      "コアの情報を表示する。")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
      "チートのパス"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
      "説明"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
      "ハードコアモード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LEADERBOARDS_ENABLE,
      "ランキング"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_BADGES_ENABLE,
      "実績バッジ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
      "解除された実績:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
      "ロックされている"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
      "レトロ実績"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
      "非公式実績をテスト"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_VERBOSE_ENABLE,
      "実績の詳細モード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_AUTO_SCREENSHOT,
      "自動スクリーンショット"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
      "解除可能の実績:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
      "解除されている"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY_HARDCORE,
      "解除されている(ハードコア)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
      "閉じる"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG,
      "コンフィグ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
      "設定をロード"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
      "設定"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
      "終了前に設定を自動保存"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
      "コレクション"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
      "コンテンツデータベース"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
      "コンテンツ"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
      "履歴リストのサイズ"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_REMOVE,
      "エントリー削除を許す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
      "クイックメニュー"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
      "ダウンロード"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
      "ダウンロード"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
      "チート"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
      "Core Counters"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
      "コアの名前を表示"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
      "コアの情報"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
      "作家"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
      "カテゴリー"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
      "コアのラベル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
      "コアの名前")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
      "ファームウェア")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
      "ライセンス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
      "許可")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
      "対応する拡張子")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
      "システムのメーカー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
      "システム名")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
      "コントロール")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_LIST,
      "コアをロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
      "オプション")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
      "コア")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
      "自動的にコアをスタート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "ダウンロードしたアーカイブを自動解凍")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
      "BuildbotのコアURL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
      "コアのアップデーター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
      "アップデーター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
      "CPUアーキテクチャ:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_CORES,
      "CPUコア数:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
      "カーソル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
      "カーソルマネージャー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
      "カスタム比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
      "データベースマネージャー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
      "データベース選択")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
      "削除")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
      "<コンテンツフォルダ>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
      "<デフォルト>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
      "<無し>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
      "そのようなフォルダはありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
      "ディレクトリ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
      "Disk Cycle Tray Status")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
      "Disk Image Append")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_INDEX,
      "ディスクインデックス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
      "ディスク設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DONT_CARE,
      "なんでもいい")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
      "ダウンロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES,
      "お気に入り")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
      "コアをダウンロード...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
      "コンテンツをダウンロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
      "DPI優先を有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
      "DPI優先")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
      "ドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
      "コアをシャットダウンでダミー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHECK_FOR_MISSING_FIRMWARE,
      "ロード前に見つからないファームウェアを探す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
      "ダイナミック壁紙")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
      "ダイナミック壁紙")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
      "有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
      "Menu entry hover color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
      "Menu entry normal color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FALSE,
      "偽")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
      "早送り比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES_TAB,
      "お気に入り")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FPS_SHOW,
      "フレームレートを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
      "フレームの減速度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
      "フレームの減速度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
      "Frontend Counters")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
      "コンテンツ特定のコア設定を自動的にロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
      "Create game-options file")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
      "Game-options file")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP,
      "ヘルプ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
      "オーディオとビデオのトラブルシューティング")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
      "バーチャルゲームパッドオーバーレイを変更すること")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
      "基本メニューコントロール")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LIST,
      "ヘルプ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
      "コンテンツをロードすること")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
      "コンテンツをスキャンすること")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
      "コアとは？")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
      "履歴リストを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
      "履歴")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
      "横メニュー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
      "画像")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION,
      "情報")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
      "情報")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
      "アナログのデジタル化のタイプ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
      "すべてのユーザーがメニューを操作できる")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
      "左アナログX")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
      "左アナログX- (左)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
      "左アナログX+ (右)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
      "左アナログY")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
      "左アナログY- (上)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
      "左アナログY+ (下)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
      "右アナログX")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
      "右アナログX- (左)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
      "右アナログX+ (右)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
      "右アナログY")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
      "右アナログY- (上)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
      "右アナログY+ (下)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
      "Gun Trigger")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
      "Gun Reload")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
      "Gun Aux A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
      "Gun Aux B")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
      "Gun Aux C")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
      "Gun Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
      "Gun Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
      "Gun D-pad Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
      "Gun D-pad Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
      "Gun D-pad Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
      "Gun D-pad Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
      "自動コンフィグを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
      "入力軸のしきい値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
      "メニューのOKとキャンセルボタンをスワップ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
      "全てをバインド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
      "全てのバインドを初期化")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
      "バインドのタイムアウト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
      "未定義のコア入力の識別子を隠す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
      "入力の識別子ラベルを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
      "デバイスインデックス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
      "デバイスタイプ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_INDEX,
      "マウスのインデックス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
      "入力のドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
      "デューティー比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
      "入力のホットキーバインド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
      "キーボードのゲームパッドマッピングを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
      "Aボタン(右)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
      "Bボタン(下)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
      "下 (十字キー)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
      "L2ボタン(トリガー)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
      "L3ボタン(親指)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
      "Lボタン(上面)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
      "左 (十字キー)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
      "R2ボタン(トリガー)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
      "R3ボタン(親指)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
      "Rボタン(上面)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
      "右 (十字キー)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
      "選択ボタン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
      "スタートボタン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
      "上 (十字キー)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
      "Xボタン(上面)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
      "Yボタン(左)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEY,
      "(キー: %s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
      "Mouse 1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
      "Mouse 2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
      "Mouse 3")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
      "Mouse 4")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
      "Mouse 5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
      "Wheel Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
      "Wheel Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
      "Wheel Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
      "Wheel Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
      "キーボードのゲームパッドマッピング式")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
      "最高のユーザー数")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "ゲームパッドのメニュー切り替えコンボ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
      "前のチートインデックス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
      "次のチートインデックス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
      "チートを切り替")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
      "ディスクを取り出し")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
      "次のディスクに切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
      "前のディスクに切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
      "ホットキーを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
      "ホールドで早送")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
      "早送りに切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
      "コマ送り")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
      "フルスクリーンに切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
      "マウスグラブを切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GAME_FOCUS_TOGGLE,
      "ゲームのフォーカスを切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_UI_COMPANION_TOGGLE,
      "デスクトップメニューを切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DESKTOP_MENU_ENABLE,
      "デスクトップメニューを有効（再起動が必要）")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
      "保存状態をロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
      "メニューに切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
      "録画")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
      "消音")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_NETPLAY_GAME_WATCH,
      "ネットプレイの観覧を切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
      "ソフトウェアキーボードを切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
      "次のオーバーレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
      "一時停止")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
      "RetroArchを終了")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
      "リセット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
      "巻き戻し")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
      "状態保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
      "スクリーンショット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
      "次のシェーダー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
      "前のシェーダー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
      "ホルドでスローモーション")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_KEY,
      "スローモーションに切り替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
      "前の状態スロット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
      "次の状態スロット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
      "音量を減る")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
      "音量を増す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
      "ディスプレイのオーバーレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
      "メニューにオーバーレイを隠す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS,
      "オーバーレイに入力を表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_SHOW_PHYSICAL_INPUTS_PORT,
      "入力表示のポート番号")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
      "ポールタイプの行動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
      "早い")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
      "遅い")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
      "普通")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
      "Prefer Front Touch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
      "入力リマップ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
      "リマップバインドを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
      "自動設定を保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
      "入力")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
      "小さいキーボードを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
      "タッチを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
      "ターボ有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
      "ターボの期間")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
      "入力ユーザー%uのバインド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LATENCY_SETTINGS,
      "遅延")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
      "内蔵ストレージ状態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
      "入力デバイスの自動設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
      "ジョイパッドのドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
      "Lakkaのサービス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
      "中国語 (簡体)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
      "中国語 (繁体)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
      "オランダ語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
      "英語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
      "エスペラント")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
      "フランス語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
      "ドイツ語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
      "イタリア語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
      "日本語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
      "韓国語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_POLISH,
      "ポーランド語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
      "ポルトガル語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
      "ポルトガル語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
      "ロシア語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
      "スペイン語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
      "ベトナム語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
      "アラビア語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
      "左のアナログ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
      "コア")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
      "コア情報")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
      "コアのログ出力レベル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LINEAR,
      "リニア")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
      "コアでアーカイブをロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
      "最近のものをロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
      "コンテンツをロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_STATE,
      "保存状態をロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
      "ロケーションを許す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
      "ロケーションのドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
      "ログ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
      "ログの出力レベル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MAIN_MENU,
      "メインメニュー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MANAGEMENT,
      "データベースの設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
      "メニューの色テーマ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
      "青")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
      "ブルーグレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
      "ダークブルー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
      "緑")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
      "シールド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
      "赤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
      "黄色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
      "フッター不透明性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
      "ヘッダー不透明性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
      "メニューのドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
      "メニューのフレームレートを減速")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS,
      "設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
      "メニューのリニアフィルター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_HORIZONTAL_ANIMATION,
      "横アニメーション")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
      "外観")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
      "メニューの壁紙")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
      "壁紙の不透明性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MISSING,
      "欠測")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MORE,
      "...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
      "マウス対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
      "マルチメディア")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
      "音楽")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "不明な拡張子を隠す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
      "ナビゲーションの回り込み")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NEAREST,
      "最近傍補間")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY,
      "ネットプレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ALLOW_SLAVES,
      "スレーブモードのクライアントを許す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
      "ネットプレイのチェックフレーム")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "入力遅延フレーム数")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "入力遅延フレーム範囲")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
      "ネットプレイの延期フレーム")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
      "切断")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
      "ネットプレイを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
      "ネットプレイサーバーに接続")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
      "ホストする")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
      "Stop netplay host")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
      "サーバーのIPアドレス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LAN_SCAN_SETTINGS,
      "ローカルネットワークをスキャン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
      "ネットプレイのクライアントを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
      "ユーザー名")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PASSWORD,
      "サーバのパスワード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PUBLIC_ANNOUNCE,
      "ネットプレイの公開アナウンス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REQUIRE_SLAVES,
      "スレーブモードのクライアント意外を拒否")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
      "ネットプレイ設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_AS_SPECTATOR,
      "ネットプレイの観覧モード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_STATELESS_MODE,
      "ネットプレイのステートレスモード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATE_PASSWORD,
      "サーバの観覧パスワード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
      "ネットプレイの観覧を有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
      "ネットプレイのTCP/UDPポート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NAT_TRAVERSAL,
      "ネットプレイのNAT通過")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
      "ネットワークコマンドを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
      "ネットワークコマンドのポート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
      "ネットワーク情報")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
      "ネットワークゲームパッド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
      "ネットワークリモートのベースポート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
      "ネットワーク")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO,
      "いいえ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NONE,
      "無し")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
      "該当なし")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
      "表示する実績はありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE,
      "コアはありません")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
      "コアはありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
      "コア情報はありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
      "コア設定はありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
      "No entries to display.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
      "履歴はありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
      "情報はありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ITEMS,
      "アイテムが見つかりません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETPLAY_HOSTS_FOUND,
      "該当するネットプレイホストが見つかりませんでした。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETWORKS_FOUND,
      "該当するネットワークが見つかりませんでした。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
      "No performance counters.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
      "プレイリストが見つかりません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
      "プレイリストのエントリーはありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
      "設定が見つかりませんでした。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
      "シェーダーのパラメータはありません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OFF,
      "OFF")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ON,
      "ON")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE,
      "オンライン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
      "オンラインアップデーター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
      "OSDディスプレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
      "OSDオーバーレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
      "OSD通知")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
      "フォルダでアーカイブを開く")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPTIONAL,
      "任意")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY,
      "オーバーレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
      "優先オーバーレイを自動ロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
      "オーバーレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
      "オーバーレイの不透明性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
      "オーバーレイのプリセット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
      "オーバーレイのスケール")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
      "OSDオーバーレイ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
      "PAL60モードを使用")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
      "親ディレクトリー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
      "メニューが表示時に一時停止")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
      "バックグラウンドで実行しない")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
      "パフォーマンスカウンター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
      "プレイリスト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
      "プレイリスト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
      "プレイリスト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
      "タッチ対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PORT,
      "ポート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRESENT,
      "現在")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
      "プライバシー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
      "終了")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
      "アナログ対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
      "BBFC評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
      "CERO評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
      "共同対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
      "CRC32")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
      "記述")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
      "開発者")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
      "Edge雑誌の発行")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
      "Edge雑誌の評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
      "Edge雑誌のレビュー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
      "ELSPA評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
      "Enhancement Hardware")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
      "ESRB評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
      "ファミ通の評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
      "フランチャイズ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
      "ジャンル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
      "MD5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
      "名前")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
      "元")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
      "PEGI評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
      "出版社")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
      "発売月")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
      "発売年")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
      "振動の対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
      "シリアル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
      "SHA1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
      "コンテンツをスタート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
      "TGDB評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REBOOT,
      "再起動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
      "録画設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
      "録画の出力")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
      "録画")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
      "録画設定ファイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
      "録画のドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
      "録画を有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_PATH,
      "出力ファイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
      "出力ディレクトリーを使用")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE,
      "リマップファイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
      "リマップファイルをロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
      "コアリマップファイルを保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
      "ゲームリマップファイルを保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_CORE,
      "コアのりマップファイルを削除")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_REMOVE_GAME,
      "ゲームのりマップファイルを削除")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REQUIRED,
      "必要")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
      "コンテンツを再起動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
      "RetroArchを再起動")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME,
      "再開")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
      "再開")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
      "レトロキーボード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD,
      "レトロパッド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
      "レトロパッド(アナログ付)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
      "レトロ実績")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
      "巻き戻しを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
      "巻き戻しの粒状度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
      "巻き戻し")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
      "ファイルブラウザー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
      "設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
      "スタート画面を表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
      "右のアナログ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN,
      "実行")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_MUSIC,
      "実行")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
      "SAMBAを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
      "セーブファイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
      "保存状態の自動インデックス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
      "自動的に保存状態をロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
      "自動的に状態を保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
      "保存状態")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_THUMBNAIL_ENABLE,
      "保存状態のサムネイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
      "現在の設定を保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "コアの優先を保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "ゲームの優先を保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
      "新しい設定を保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_STATE,
      "状態保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
      "保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
      "フォルダをスキャン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_FILE,
      "ファイルをスキャン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
      "<このフォルダをスキャン>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
      "スクリーンショット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
      "スクリーン解像度")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SEARCH,
      "検索")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SECONDS,
      "秒")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS,
      "設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
      "設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER,
      "シェーダー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
      "シェーダーの変更点を適用")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
      "シェーダー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
      "リボン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
      "リボン (単純)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
      "単純な雪")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
      "雪")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
      "詳細設定を表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
      "隠しファイルとフォルダを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHUTDOWN,
      "シャットダウン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
      "スローモーション比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_AHEAD_ENABLED,
      "先読みして遅延を減らす")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_AHEAD_FRAMES,
      "先読みするフレーム数")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN_AHEAD_SECONDARY_INSTANCE,
      "２つ目のコアで先読みする")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
      "フォルダでセーブファイルを並び替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
      "フォルダで保存状態を並び替え")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATES_IN_CONTENT_DIR_ENABLE,
      "コンテンツフォルダに保存状態を書き込む")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILES_IN_CONTENT_DIR_ENABLE,
      "コンテンツフォルダにセーブファイルを書き込む")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEMFILES_IN_CONTENT_DIR_ENABLE,
      "コンテンツフォルダからシステムファイルを読み込む")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOTS_IN_CONTENT_DIR_ENABLE,
      "コンテンツフォルダにスクリーンショットを書き込む")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
      "SSHを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_CORE,
      "コアをスタート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
      "リモートレトロパッドをスタート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
      "ビデオプロセッサをスタート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATE_SLOT,
      "保存状態のスロット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATUS,
      "ステータス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
      "stdinコマンド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
      "提案するコア")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
      "スクリーンセーバーをサスペンド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
      "System BGM Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
      "システム/BIOS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
      "システム情報")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
      "7zip対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
      "ALSA対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
      "ビルド日付")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
      "Cg対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
      "Cocoa対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
      "コマンドインタフェース対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
      "CoreText対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
      "CPU機能")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
      "ディスプレイの軽量DPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
      "ディスプレイの軽量縦幅 (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
      "ディスプレイの軽量横幅 (mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
      "DirectSound対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
      "WASAPI対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
      "ダイナミックライブラリー対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
      "ダイナミックlibretroライブラリーのランタイム時にロード対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
      "EGL対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
      "OpenGL/Direct3Dテクスチャーにレンダリング (マルチパスシェーダー)対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
      "FFmpeg対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
      "FreeType対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
      "フロントエンド識別名")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
      "フロントエンド名")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
      "フロントエンドOS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
      "Gitバージョン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
      "GLSL対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
      "HLSL対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
      "JACK対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
      "KMS/EGL対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LAKKA_VERSION,
      "Lakkaバージョン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
      "LibretroDB対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
      "Libusb対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
      "libxml2 XMLパース対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
      "ネットプレイ(ピアツーピア)対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
      "ネットワークコマンドインタフェース対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
      "ネットワークゲームパッド対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
      "OpenAL対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
      "OpenGL ES対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
      "OpenGL対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
      "OpenSL対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
      "OpenVG対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
      "OSS対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
      "オーバーレイ対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
      "パワーソース")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
      "充電完了")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
      "充電中")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
      "放電")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
      "ソースはありません")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
      "PulseAudio対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
      "Python(シェーダーにスクリプト)対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
      "BMP対応 (RBMP)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
      "RetroRatingレベル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
      "JPEG対応 (RJPEG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
      "RoarAudio対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
      "PNG対応 (RPNG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
      "RSound対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
      "TGA対応 (RTGA)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
      "SDL2対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
      "SDLイメージ対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
      "SDL1.2対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
      "Slang対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
      "スレッド対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
      "Udev対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
      "Video4Linux2対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
      "ビデオのコンテクストドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
      "Vulkan対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
      "Wayland対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
      "X11対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
      "XAudio2対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
      "XVideo対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
      "Zlib対応")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
      "スクリーンショットを撮る")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE,
      "スレッド化タスク")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS,
      "サムネイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_THUMBNAILS,
      "左のサムネイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_VERTICAL_THUMBNAILS,
      "サムネイル両方を右側に設置")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
      "サムネイル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
      "サムネイルのアップデーター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
      "ボックスアート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
      "スクリーンショット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
      "タイトルスクリーン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
      "日付と時刻を表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
      "メニューのタイトル色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TRUE,
      "真")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
      "UI Companion Enable")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
      "UI Companion Start On Boot")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_TOGGLE,
      "起動時にデスクトップメニューを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
      "メニューバー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
      "圧縮ファイルの読み込みは失敗しました。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
      "保存状態のロードを前に戻す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
      "状態の保存を前に戻す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNKNOWN,
      "不明")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
      "アップデーター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
      "資産をアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
      "自動コンフィグプロファイルをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
      "Cgシェーダーをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
      "チートをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
      "コアの情報ファイルをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
      "データベースをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
      "GLSLシェーダーをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
      "Lakkaをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
      "オーバーレイをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
      "Slangシェーダーをアップデート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER,
      "ユーザー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
      "ユーザーインタフェース")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
      "言語")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
      "ユーザー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
      "内蔵の画像ビューアを使用")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
      "内蔵のメディアプレイヤーを使用")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
      "<このフォルダを使用>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
      "回転を許す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO,
      "コンフィグのアスペクト比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
      "自動アスペクト比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
      "アスペクト比")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
      "黒いフレームを挿入")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
      "オーバースキャンをクロップ（再起動が必要）")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
      "デスクトップのコンポジットを無効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
      "ビデオのドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
      "ビデオのフィルター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
      "ビデオフィルター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
      "Flicker filter")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
      "OSDメッセージを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
      "OSDメッセージのフォント")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
      "OSDメッセージのサイズ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
      "アスペクト比を強制")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
      "sRGB FBOを強制無効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
      "フレームの遅れ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
      "フルスクリーンモード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
      "ビデオのガンマ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
      "GPUの録画を有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
      "GPUスクリーンショットを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
      "強制GPU同期")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
      "強制GPU同期フレーム")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "最高のスワップチェーンイメージ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
      "OSDメッセージのX位置")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
      "OSDメッセージのY位置")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
      "モニタのインデックス")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
      "事後フィルターの録画を有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
      "リフレッシュレート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
      "画面の予想フレームレート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
      "Set Display-Reported Refresh Rate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
      "回転")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
      "ウィンドウのスケール")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
      "整数スケール")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
      "ビデオ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
      "ビデオシェーダー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
      "シェーダーのパス数")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
      "シェーダーパラメータのプレビュー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
      "シェーダーのプリセットをロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
      "シェーダーのプリセットを名前を付けて保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
      "コアのプリセットを保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
      "ゲームのプリセットを保存")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
      "ハードウェアの共有コンテキストを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
      "ハードウェアのバイリニアフィルター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
      "ソフトフィルターを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
      "VSYNCのスワップ期間")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
      "ビデオ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
      "スレッドされているビデオ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
      "非フリッカー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "カスタムのビューポートの縦幅")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "カスタムのビューポートの横幅")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
      "カスタムのビューポートのX")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
      "カスタムのビューポートのY")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
      "Set VI Screen Width")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
      "VSYNC")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
      "ウィンドウのフルスクリーンモード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
      "ウィンドウの幅")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
      "ウィンドウの縦")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_X,
      "フルスクリーンの幅")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN_Y,
      "フルスクリーンの縦")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
      "Wi-Fiのドライバ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
      "Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
      "メニューの透明性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_RED,
      "メニューフォントの赤色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_GREEN,
      "メニューフォントの緑色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_BLUE,
      "メニューフォントの青色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_FONT,
      "メニューのフォント")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
      "カスタム")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
      "フラットUI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
      "モノクローム")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
      "モノクローム Inverted")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
      "システマティック")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
      "ネオアクティブ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
      "ピクセル")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
      "レトロアクティブ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
      "Retrosystem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
      "ドット絵")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
      "メニューの色テーマ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
      "りんご緑")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
      "ダーク")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LIGHT,
      "ライト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
      "ぶどう色")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
      "電子ブルー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
      "ゴールデン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
      "レガシーレッド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
      "ミッドナイトブルー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
      "プレーン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
      "海底")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
      "火山レッド")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
      "メニューのシェーダーパイプライン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
      "メニューの倍率")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
      "アイコンの影を有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
      "履歴タブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_ADD,
      "コンテンツをインポートするタブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_PLAYLISTS,
      "プレイリストタブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_FAVORITES,
      "お気に入りタブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
      "画像タブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
      "音楽タブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
      "設定タブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
      "ビデオタブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_NETPLAY,
      "ネットプレイタブを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "メニュー配置")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_THEME,
      "メニューのアイコンテーマ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_YES,
      "はい")
MSG_HASH(MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
      "シェーダーのプリセット")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
      "Enable or disable achievements. For more information, visit http://retroachievements.org")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
      "Enable or disable unofficial achievements and/or beta features for testing purposes.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
      "保存状態、チート、巻き戻し、早送り、一時停止、スローモーションを全部のゲームに無効する。")
MSG_HASH(MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
      "システムのドライバを変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
      "実績関係の設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_SETTINGS,
      "コアの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
      "録画の設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
      "OSDオーバーレイ、キーボードオーバーレイ、OSDメッセージの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
      "巻き戻し、早送り、スローモーションの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
      "保存関係の設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
      "ログの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
      "ユーザーインタフェースの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_SETTINGS,
      "アカウント、ユーザー名、言語を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
      "プライバシー設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
      "このシステムの初期ディレクトリーを変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
      "プレイリストの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
      "ネットワークの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
      "コンテンツをスキャンしてデータベースに入れる。")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
      "オーディオ出力の設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
      "Bluetoothを有効する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
      "終了時に設定を自動的に保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
      "コンフィグファイルのデフォルト設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
      "コンフィグファイルを管理と作成する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CPU_CORES,
      "CPUのコア数")
MSG_HASH(MENU_ENUM_SUBLABEL_FPS_SHOW,
      "画面で現在のフレームレートを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
      "ホットキー設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "メニューに切り替えるゲームパッドのボタンコンボ")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
      "ゲームパッド、キーボード、マウスの設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
      "このユーザーの入力設定を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
      "端末にログすることを有効と無効。")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY,
      "ネットプレイのセッションを参加やホストする。")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_LAN_SCAN_SETTINGS,
      "ローカルネットワーク上のネットプレイホストをスキャンと接続する。")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
      "コア、ネットワーク、システムの詳細を表示する。\nデータベースとカーソルのマネジャーを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
      "RetroArchにアドオン、コンポーネント、コンテンツをダウンロードする。")
MSG_HASH(MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
      "フォルダのネットワーク共有を有効する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
      "OS関係のサービスを管理する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
      "ファイルブラウザーの中に隠しファイルとフォルダを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SSH_ENABLE,
      "SSHでのアクセスを有効する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
      "システムのスクリーンセーバーをアクティブになることを予防する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_SCALE,
      "Sets the window size relative to the core viewport size. Alternatively you can set a window width and height below for a fixed window size")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_LANGUAGE,
      "インタフェースの言語を変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
      "フレームの間で黒フレームを挿入する。60Hzコンテンツを120Hz画面でやることを役に立つ。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
      "遅延が減るけどビデオ途切れの危険率が増す。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
      "CPUが「強制GPU同期」を使用時にGPUからの最高のフレーム前進を選択する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "指定するバッファーモードをビデオドライバに伝える。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
      "希望する画面を選択する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
      "画面の正確な推定のリフレッシュレート")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
      "The refresh rate as reported by the display driver.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
      "ビデオ出力の設定を変える。")
MSG_HASH(MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
      "無線ネットワークを検索して接続する。")
MSG_HASH(MENU_ENUM_SUBLABEL_HELP_LIST,
      "RetroArchの使い方について学ぶ。")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
      "チートの変更点が今すぐに適用する。")
MSG_HASH(MSG_ADDED_TO_FAVORITES,
      "お気に入りに追加しました")
MSG_HASH(MSG_APPENDED_DISK,
      "ディスクを追加しました。")
MSG_HASH(MSG_APPLICATION_DIR,
      "アプリフォルダ")
MSG_HASH(MSG_APPLYING_CHEAT,
      "Applying cheat changes.")
MSG_HASH(MSG_APPLYING_SHADER,
      "Applying shader")
MSG_HASH(MSG_AUDIO_MUTED,
      "消音。")
MSG_HASH(MSG_AUDIO_UNMUTED,
      "消音解除。")
MSG_HASH(MSG_AUTOCONFIG_FILE_ERROR_SAVING,
      "Error saving autoconf file.")
MSG_HASH(MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
      "Autoconfig file saved successfully.")
MSG_HASH(MSG_AUTOSAVE_FAILED,
      "Could not initialize autosave.")
MSG_HASH(MSG_AUTO_SAVE_STATE_TO,
      "Auto save state to")
MSG_HASH(MSG_BLOCKING_SRAM_OVERWRITE,
      "Blocking SRAM Overwrite")
MSG_HASH(MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
      "Bringing up command interface on port")
MSG_HASH(MSG_BYTES,
      "バイト")
MSG_HASH(MSG_CANNOT_INFER_NEW_CONFIG_PATH,
      "Cannot infer new config path. Use current time.")
MSG_HASH(MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
      "ハードコアモードが有効された。保存状態と巻き戻しは無効になった。")
MSG_HASH(MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
      "Comparing with known magic numbers...")
MSG_HASH(MSG_COMPILED_AGAINST_API,
      "Compiled against API")
MSG_HASH(MSG_CONFIG_DIRECTORY_NOT_SET,
      "Config directory not set. Cannot save new config.")
MSG_HASH(MSG_CONNECTED_TO,
      "Connected to")
MSG_HASH(MSG_CONTENT_CRC32S_DIFFER,
      "Content CRC32s differ. Cannot use different games.")
MSG_HASH(MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
      "Content loading skipped. Implementation will load it on its own.")
MSG_HASH(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
      "コアは保存状態の対応がありません。")
MSG_HASH(MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
      "Core options file created successfully.")
MSG_HASH(MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
      "Could not find any next driver")
MSG_HASH(MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
      "Could not find compatible system.")
MSG_HASH(MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
      "Could not find valid data track")
MSG_HASH(MSG_COULD_NOT_OPEN_DATA_TRACK,
      "could not open data track")
MSG_HASH(MSG_COULD_NOT_READ_CONTENT_FILE,
      "コンテンツファイルの読み込みはできませんでした")
MSG_HASH(MSG_COULD_NOT_READ_MOVIE_HEADER,
      "Could not read movie header.")
MSG_HASH(MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
      "Could not read state from movie.")
MSG_HASH(MSG_CRC32_CHECKSUM_MISMATCH,
      "CRC32 checksum mismatch between content file and saved content checksum in replay file header) replay highly likely to desync on playback.")
MSG_HASH(MSG_CUSTOM_TIMING_GIVEN,
      "Custom timing given")
MSG_HASH(MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
      "Decompression already in progress.")
MSG_HASH(MSG_DECOMPRESSION_FAILED,
      "Decompression failed.")
MSG_HASH(MSG_DETECTED_VIEWPORT_OF,
      "Detected viewport of")
MSG_HASH(MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
      "Did not find a valid content patch.")
MSG_HASH(MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
      "Disconnect device from a valid port.")
MSG_HASH(MSG_DISK_CLOSED,
      "閉域")
MSG_HASH(MSG_DISK_EJECTED,
      "取り出された")
MSG_HASH(MSG_DOWNLOADING,
      "ダウンロード中")
MSG_HASH(MSG_DOWNLOAD_FAILED,
      "ダウンロード失敗")
MSG_HASH(MSG_ERROR,
      "エラー")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
      "Libretro core requires content, but nothing was provided.")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
      "Libretro core requires special content, but none were provided.")
MSG_HASH(MSG_ERROR_PARSING_ARGUMENTS,
      "Error parsing arguments.")
MSG_HASH(MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
      "コアのオプションファイルを保存に失敗しました。")
MSG_HASH(MSG_ERROR_SAVING_REMAP_FILE,
      "リマップファイルを保存に失敗しました。")
MSG_HASH(MSG_ERROR_REMOVING_REMAP_FILE,
      "リマップファイルを削除に失敗しました。")
MSG_HASH(MSG_ERROR_SAVING_SHADER_PRESET,
      "シェーダーのプリセットを保存に失敗しました。")
MSG_HASH(MSG_EXTERNAL_APPLICATION_DIR,
      "外部アプリフォルダ")
MSG_HASH(MSG_EXTRACTING,
      "解凍中")
MSG_HASH(MSG_EXTRACTING_FILE,
      "ファイルを解凍中")
MSG_HASH(MSG_FAILED_SAVING_CONFIG_TO,
      "Failed saving config to")
MSG_HASH(MSG_FAILED_TO,
      "Failed to")
MSG_HASH(MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
      "Failed to accept incoming spectator.")
MSG_HASH(MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
      "Failed to allocate memory for patched content...")
MSG_HASH(MSG_FAILED_TO_APPLY_SHADER,
      "Failed to apply shader.")
MSG_HASH(MSG_FAILED_TO_BIND_SOCKET,
      "Failed to bind socket.")
MSG_HASH(MSG_FAILED_TO_CREATE_THE_DIRECTORY,
      "Failed to create the directory.")
MSG_HASH(MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
      "Failed to extract content from compressed file")
MSG_HASH(MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
      "Failed to get nickname from client.")
MSG_HASH(MSG_FAILED_TO_LOAD,
      "ロードに失敗")
MSG_HASH(MSG_FAILED_TO_LOAD_CONTENT,
      "コンテンツをロードに失敗しました。")
MSG_HASH(MSG_FAILED_TO_LOAD_MOVIE_FILE,
      "Failed to load movie file")
MSG_HASH(MSG_FAILED_TO_LOAD_OVERLAY,
      "Failed to load overlay.")
MSG_HASH(MSG_FAILED_TO_LOAD_STATE,
      "Failed to load state from")
MSG_HASH(MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
      "コアをロードするに失敗しました")
MSG_HASH(MSG_FAILED_TO_PATCH,
      "パッチに失敗しました")
MSG_HASH(MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
      "Failed to receive header from client.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME,
      "Failed to receive nickname.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
      "Failed to receive nickname from host.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
      "Failed to receive nickname size from host.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
      "Failed to receive SRAM data from host.")
MSG_HASH(MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
      "Failed to remove disk from tray.")
MSG_HASH(MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
      "Failed to remove temporary file")
MSG_HASH(MSG_FAILED_TO_SAVE_SRAM,
      "Failed to save SRAM")
MSG_HASH(MSG_FAILED_TO_SAVE_STATE_TO,
      "Failed to save state to")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME,
      "Failed to send nickname.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_SIZE,
      "Failed to send nickname size.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
      "Failed to send nickname to client.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
      "Failed to send nickname to host.")
MSG_HASH(MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
      "Failed to send SRAM data to client.")
MSG_HASH(MSG_FAILED_TO_START_AUDIO_DRIVER,
      "Failed to start audio driver. Will continue without audio.")
MSG_HASH(MSG_FAILED_TO_START_MOVIE_RECORD,
      "Failed to start movie record.")
MSG_HASH(MSG_FAILED_TO_START_RECORDING,
      "Failed to start recording.")
MSG_HASH(MSG_FAILED_TO_TAKE_SCREENSHOT,
      "Failed to take screenshot.")
MSG_HASH(MSG_FAILED_TO_UNDO_LOAD_STATE,
      "Failed to undo load state.")
MSG_HASH(MSG_FAILED_TO_UNDO_SAVE_STATE,
      "Failed to undo save state.")
MSG_HASH(MSG_FAILED_TO_UNMUTE_AUDIO,
      "Failed to unmute audio.")
MSG_HASH(MSG_FATAL_ERROR_RECEIVED_IN,
      "Fatal error received in")
MSG_HASH(MSG_FILE_NOT_FOUND,
      "そのようなファイルはありません。")
MSG_HASH(MSG_FOUND_AUTO_SAVESTATE_IN,
      "Found auto savestate in")
MSG_HASH(MSG_FOUND_DISK_LABEL,
      "Found disk label")
MSG_HASH(MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
      "Found first data track on file")
MSG_HASH(MSG_FOUND_LAST_STATE_SLOT,
      "Found last state slot")
MSG_HASH(MSG_FOUND_SHADER,
      "Found shader")
MSG_HASH(MSG_FRAMES,
      "フレーム")
MSG_HASH(MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
      "Per-Game Options: game-specific core options found at")
MSG_HASH(MSG_GOT_INVALID_DISK_INDEX,
      "Got invalid disk index.")
MSG_HASH(MSG_GRAB_MOUSE_STATE,
      "マウスステートをグラブする")
MSG_HASH(MSG_GAME_FOCUS_ON,
      "ゲームフォーカスをオンにしました。")
MSG_HASH(MSG_GAME_FOCUS_OFF,
      "ゲームフォーカスをオフにしました。")
MSG_HASH(MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
      "Libretro core is hardware rendered. Must use post-shaded recording as well.")
MSG_HASH(MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
      "Inflated checksum did not match CRC32.")
MSG_HASH(MSG_INPUT_CHEAT,
      "Input Cheat")
MSG_HASH(MSG_INPUT_CHEAT_FILENAME,
      "Input Cheat Filename")
MSG_HASH(MSG_INPUT_PRESET_FILENAME,
      "Input Preset Filename")
MSG_HASH(MSG_INPUT_RENAME_ENTRY,
      "Rename Title")
MSG_HASH(MSG_INTERFACE,
      "インタフェース")
MSG_HASH(MSG_INTERNAL_STORAGE,
      "内蔵ストレージ")
MSG_HASH(MSG_REMOVABLE_STORAGE,
      "リムーバブルストレージ")
MSG_HASH(MSG_INVALID_NICKNAME_SIZE,
      "Invalid nickname size.")
MSG_HASH(MSG_IN_BYTES,
      "(バイトで)")
MSG_HASH(MSG_IN_GIGABYTES,
      "(ギガバイトで)")
MSG_HASH(MSG_IN_MEGABYTES,
      "(メガバイトで)")
MSG_HASH(MSG_LIBRETRO_ABI_BREAK,
      "is compiled against a different version of libretro than this libretro implementation.")
MSG_HASH(MSG_LIBRETRO_FRONTEND,
      "libretroのフロントエンド")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT,
      "スロット%dから保存状態をロードしました。")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT_AUTO,
      "スロット-1 (自動)から保存状態をロードしました。")
MSG_HASH(MSG_LOADING,
      "ロード中")
MSG_HASH(MSG_FIRMWARE,
      "ファームウェアファイルが見つかりませんでした。")
MSG_HASH(MSG_LOADING_CONTENT_FILE,
      "コンテンツをロード中")
MSG_HASH(MSG_LOADING_HISTORY_FILE,
      "履歴ファイルをロード中")
MSG_HASH(MSG_LOADING_STATE,
      "保存状態をロード中")
MSG_HASH(MSG_MEMORY,
      "メモリ")
MSG_HASH(MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
      "Movie file is not a valid BSV1 file.")
MSG_HASH(MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
      "Movie format seems to have a different serializer version. Will most likely fail.")
MSG_HASH(MSG_MOVIE_PLAYBACK_ENDED,
      "Movie playback ended.")
MSG_HASH(MSG_MOVIE_RECORD_STOPPED,
      "Stopping movie record.")
MSG_HASH(MSG_NETPLAY_FAILED,
      "Failed to initialize netplay.")
MSG_HASH(MSG_NO_CONTENT_STARTING_DUMMY_CORE,
      "No content, starting dummy core.")
MSG_HASH(MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
      "No save state has been overwritten yet.")
MSG_HASH(MSG_NO_STATE_HAS_BEEN_LOADED_YET,
      "No state has been loaded yet.")
MSG_HASH(MSG_OVERRIDES_ERROR_SAVING,
      "Error saving overrides.")
MSG_HASH(MSG_OVERRIDES_SAVED_SUCCESSFULLY,
      "優先ファイルを保存しました。")
MSG_HASH(MSG_PAUSED,
      "一時停止。")
MSG_HASH(MSG_PROGRAM,
      "RetroArch")
MSG_HASH(MSG_READING_FIRST_DATA_TRACK,
      "Reading first data track...")
MSG_HASH(MSG_RECEIVED,
      "received")
MSG_HASH(MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
      "Recording terminated due to resize.")
MSG_HASH(MSG_RECORDING_TO,
      "Recording to")
MSG_HASH(MSG_REDIRECTING_CHEATFILE_TO,
      "Redirecting cheat file to")
MSG_HASH(MSG_REDIRECTING_SAVEFILE_TO,
      "Redirecting save file to")
MSG_HASH(MSG_REDIRECTING_SAVESTATE_TO,
      "Redirecting savestate to")
MSG_HASH(MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
      "リマップファイルを保存しました。")
MSG_HASH(MSG_REMAP_FILE_REMOVED_SUCCESSFULLY,
      "リマップファイルを削除しました。")
MSG_HASH(MSG_REMOVED_DISK_FROM_TRAY,
      "Removed disk from tray.")
MSG_HASH(MSG_REMOVING_TEMPORARY_CONTENT_FILE,
      "Removing temporary content file")
MSG_HASH(MSG_RESET,
      "リセット")
MSG_HASH(MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
      "Restarting recording due to driver reinit.")
MSG_HASH(MSG_RESTORED_OLD_SAVE_STATE,
      "Restored old save state.")
MSG_HASH(MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
      "Shaders: restoring default shader preset to")
MSG_HASH(MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
      "Reverting savefile directory to")
MSG_HASH(MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
      "Reverting savestate directory to")
MSG_HASH(MSG_REWINDING,
      "巻き戻しています。")
MSG_HASH(MSG_REWIND_INIT,
      "Initializing rewind buffer with size")
MSG_HASH(MSG_REWIND_INIT_FAILED,
      "Failed to initialize rewind buffer. Rewinding will be disabled.")
MSG_HASH(MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
      "Implementation uses threaded audio. Cannot use rewind.")
MSG_HASH(MSG_REWIND_REACHED_END,
      "Reached end of rewind buffer.")
MSG_HASH(MSG_SAVED_NEW_CONFIG_TO,
      "Saved new config to")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT,
      "スロット%dに状態を保存しました。")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT_AUTO,
      "スロット-1 (自動)に状態を保存しました。")
MSG_HASH(MSG_SAVED_SUCCESSFULLY_TO,
      "Saved successfully to")
MSG_HASH(MSG_SAVING_RAM_TYPE,
      "Saving RAM type")
MSG_HASH(MSG_SAVING_STATE,
      "状態を保存中")
MSG_HASH(MSG_SCANNING,
      "スキャン中")
MSG_HASH(MSG_SCANNING_OF_DIRECTORY_FINISHED,
      "ディレクトリーのスキャンは完了しました。")
MSG_HASH(MSG_SENDING_COMMAND,
      "Sending command")
MSG_HASH(MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
      "Several patches are explicitly defined, ignoring all...")
MSG_HASH(MSG_SHADER,
      "シェーダー")
MSG_HASH(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
      "Shader preset saved successfully.")
MSG_HASH(MSG_SKIPPING_SRAM_LOAD,
      "Skipping SRAM load.")
MSG_HASH(MSG_SLOW_MOTION,
      "スローモーション。")
MSG_HASH(MSG_FAST_FORWARD,
      "早送り。")
MSG_HASH(MSG_SLOW_MOTION_REWIND,
      "スローモーション巻き戻し。")
MSG_HASH(MSG_SRAM_WILL_NOT_BE_SAVED,
      "SRAM will not be saved.")
MSG_HASH(MSG_STARTING_MOVIE_PLAYBACK,
      "Starting movie playback.")
MSG_HASH(MSG_STARTING_MOVIE_RECORD_TO,
      "Starting movie record to")
MSG_HASH(MSG_STATE_SIZE,
      "状態のサイズ")
MSG_HASH(MSG_STATE_SLOT,
      "保存状態のスロット")
MSG_HASH(MSG_TAKING_SCREENSHOT,
      "スクリーンショットを撮っています。")
MSG_HASH(MSG_TO,
      "to")
MSG_HASH(MSG_UNDID_LOAD_STATE,
      "保存状態のロードを前に戻した。")
MSG_HASH(MSG_UNDOING_SAVE_STATE,
      "Undoing save state")
MSG_HASH(MSG_UNKNOWN,
      "不明")
MSG_HASH(MSG_UNPAUSED,
      "一時停止が解除された。")
MSG_HASH(MSG_UNRECOGNIZED_COMMAND,
      "Unrecognized command")
MSG_HASH(MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
      "Using core name for new config.")
MSG_HASH(MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
      "Using libretro dummy core. Skipping recording.")
MSG_HASH(MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
      "Connect device from a valid port.")
MSG_HASH(MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
      "Disconnecting device from port")
MSG_HASH(MSG_VALUE_REBOOTING,
      "再起動しています。。。")
MSG_HASH(MSG_VALUE_SHUTTING_DOWN,
      "シャットダウンしています。。。")
MSG_HASH(MSG_VERSION_OF_LIBRETRO_API,
      "Version of libretro API")
MSG_HASH(MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
      "Viewport size calculation failed! Will continue using raw data. This will probably not work right ...")
MSG_HASH(MSG_VIRTUAL_DISK_TRAY,
      "virtual disk tray.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
      "ミリ秒でのオーディオ遅延。ドライバ対応による。")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MUTE,
      "オーディオを消音する。")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
      "Helps smooth out imperfections in timing when synchronizing audio and video at the same time. Be aware that if disabled, proper synchronization is nearly impossible to obtain."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
      "コアでのカメラ使用を許す。")
MSG_HASH(MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
      "コアでの位置情報サービスを許す。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
      "RetroArchに最大対応のユーザー数")
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
      "Influence how input polling is done inside RetroArch. Setting it to 'Early' or 'Late' can result in less latency, depending on your configuration."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
      "どれでもユーザーがメニューを操作できる。オフにすると、ユーザー１のみが操作できる。")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
      "Audio volume (in dB). 0 dB is normal volume, no gain applied."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SYNC,
      "オーディオを同期する。推奨。")
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
   "How far an axis must be tilted to result in a button press."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
   "Amount of seconds to wait until proceeding to the next bind."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
   "Describes the period of which turbo-enabled buttons toggle. Numbers are described in frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
   "Describes how long the period of a turbo-enabled button should be. Numbers are described in frames."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
   "Synchronizes the output video of the graphics card to the refresh rate of the screen. Recommended."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
   "Allow cores to set rotation. When disabled, rotation requests are ignored. Useful for setups where one manually rotates the screen."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
   "Some cores might have a shutdown feature. If enabled, it will prevent the core from shutting RetroArch down. Instead, it loads a dummy core."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
   "Check if all the required firmware is present before attempting to load content."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
   "スクリーンの垂直周波数。適当なオーディオ入力レートを計算するために使用する。備考: 「スレッドされているビデオ」という設定は有効にするとレートが無視します。"
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
   "オーディオ出力を有効する。"
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
   "The maximum change in audio input rate. You may want to increase this to enable very large changes in timing, for example running PAL cores on NTSC displays, at the cost of inaccurate audio pitch."
   )
MSG_HASH(
   MSG_FAILED,
   "失敗"
   )
MSG_HASH(
   MSG_SUCCEEDED,
   "成功しました"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED,
   "設定されていない"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
   "not configured, using fallback"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
   "データベースのカーソル表"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
   "データベース - 検索条件 : 開発者"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
   "データベース - 検索条件 : 出版社"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DISABLED,
   "無効"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_ENABLED,
   "有効"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
   "コンテンツの履歴ディレクトリ"
   )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
      "データベース - 検索条件 : Origin")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
      "データベース - 検索条件 : Franchise")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
      "データベース - 検索条件 : ESRB評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
      "データベース - 検索条件 : ELSPA評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
      "データベース - 検索条件 : PEGI評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
      "データベース - 検索条件 : CERO評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
      "データベース - 検索条件 : BBFC評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
      "データベース - 検索条件 : Max Users")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
      "データベース - 検索条件 : Releasedate By Month")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
      "データベース - 検索条件 : Releasedate By Year")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
      "データベース - 検索条件 : Edge Magazine Issue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
      "データベース - 検索条件 : Edge Magazine評価")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
      "データベース情報")
MSG_HASH(MSG_WIFI_SCAN_COMPLETE,
      "Wi-Fiスキャン完了。")
MSG_HASH(MSG_SCANNING_WIRELESS_NETWORKS,
      "無線ネットワークをスキャン中")
MSG_HASH(MSG_NETPLAY_LAN_SCAN_COMPLETE,
      "ネットプレイスキャン完了。")
MSG_HASH(MSG_NETPLAY_LAN_SCANNING,
      "ネットプレイホストをスキャン中")
MSG_HASH(MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
      "Pause gameplay when window focus is lost.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
      "Enable or disable composition.")
MSG_HASH(MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
      "Enable or disable recent playlist for games, images, music, and videos.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
      "Limit the number of entries in recent playlist for games, images, music, and videos.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
      "統一的なメニューコントロール")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
      "Use the same controls for both the menu and the game. Applies to the keyboard.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
      "OSDメッセージを表する。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_USER_REMOTE_ENABLE,
      "ユーザー%dのリモートを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_BATTERY_LEVEL_ENABLE,
      "電池残量を表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FILE,
      "ファイル選択")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FROM_COLLECTION,
      "コレクションから選択")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER,
      "フィルター")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCALE,
      "スケール")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_WHEN_LOADED,
      "コンテンツをロードする後にネットプレイは開始します。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LOAD_CONTENT_MANUALLY,
      "該当するコアやコンテンツファイルが見つかりませんでした。手動でロードしてください。")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
      "URLを参照"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL,
      "URLのパス"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_START,
      "スタート"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
      "ボケ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOWFLAKE,
      "スノーフレーク")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
      "ルーム表を更新")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
      "ニックネーム: %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
      "Nickname (lan): %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
      "対応するコンテンツが見つかりました")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
      "Cuts off a few pixels around the edges of the image that were customarily left blank by developers and sometimes contain garbage pixels.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
      "Add a slight blur to the image to take the edge off of the hard pixel edges. This option has very little impact on performance.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FILTER,
      "Apply a CPU-powered video filter. NOTE: Might come at a high performance cost. Some video filters might only work for cores that use 32bit or 16bit color.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
      "レトロ実績上のユーザー名")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
      "レトロ実績上のパスワード")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
      "ネットプレイの使用するニックネーム")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
      "Capture the image after filters (but not shaders) are applied. Your video will look as fancy as what you see on your screen.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_LIST,
      "使用するコアを選択する。")
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
      "起動するコンテンツを選択する。")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
      "ネットワークインタフェースとIPアドレスを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
      "デバイス特定の仕様")
MSG_HASH(MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
      "アプリを終了する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
      "ディスプレイのカスタムビデオ横幅を設定する。ゼロを設定すると出来るだけウィンドーをスケールする。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
      "ディスプレイのカスタムビデオ縦幅を設定する。ゼロを設定すると出来るだけウィンドーをスケールする。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
      "OSDのカスタムX軸を指定する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
      "OSDのカスタムY軸を指定する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
      "ポイントでのフォントサイズ")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
      "Hide the overlay while we are inside the menu, and show it again when exiting the menu.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
      "Content which has been scanned will appear here."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
      "Only scales video in integer steps. The base size depends on system-reported geometry and aspect ratio. If 'Force Aspect' is not set, X/Y will be integer scaled independently."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
      "GPUのシェードした出力のスクリーンショットを使用する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
      "Forces a certain rotation of the screen. The rotation is added to rotations which the core sets."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
      "Forcibly disable sRGB FBO support. Some Intel OpenGL drivers on Windows have video problems with sRGB FBO support if this is enabled. Enabling this can work around it."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
      "フルスクリーンで起動する。実行時にも切り替えできる。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
      "フルスクリーンであればウィンドーのフルスクリーンモードを使用する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
      "GPUのシェードした出力を録画する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
      "When saving a savestate, save state index is automatically increased before it is saved. Also, when loading content, the index will be set to the highest existing index."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
      "Block Save RAM from being overwritten when loading save states. Might potentially lead to buggy games."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
      "The maximum rate at which content will be run when using fast forward (E.g. 5x for 60 fps content => 300 fps cap). If this is set at 0x, then fastforward ratio is unlimited (no FPS cap)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
      "When slowmotion, content will slow down by a factor."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_ENABLE,
      "Enable rewinding. This will take a performance hit when playing."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
      "When rewinding defined number of frames, you can rewind several frames at a time, increasing the rewind speed."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
      "Sets log level for cores. If a log level issued by a core is below this value, it is ignored."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
      "Enable performance counters for RetroArch (and cores)."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
      "Automatically saves a savestate at the end of RetroArch's lifetime. RetroArch will automatically load this savestate if 'Savestate Auto Load' is set."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
      "Automatically load the auto save state on startup."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
      "Show thumbnails of save states inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
      "Autosaves the non-volatile Save RAM at a regular interval. This is disabled by default unless set otherwise. The interval is measured in seconds. A value of 0 disables autosave."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
      "If enabled, overrides the input binds with the remapped binds set for the current core."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
      "Enable input auto-detection. Will attempt to autoconfigure joypads, Plug-and-Play style."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
      "Swap buttons for OK/Cancel. Disabled is the Japanese button orientation, enabled is the western orientation."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
      "If disabled, the content will keep running in the background when we are in the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
      "使用するビデオドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
      "使用するオーディオドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_DRIVER,
      "使用する入力ドライバ。ビデオドライバによると、別の入力ドライバを強制される可能性がある。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
      "使用するジョイパッドドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
      "使用するオーディオリサンプラーのドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
      "使用するカメラドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
      "使用する位置情報ドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_DRIVER,
      "使用するメニュードライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RECORD_DRIVER,
      "使用する録画ドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_WIFI_DRIVER,
      "使用するWi-Fiドライバ"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "Filter files being shown in filebrowser by supported extensions."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
      "Select an image to set as menu wallpaper."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
      "Dynamically load a new wallpaper depending on context."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
      "Override the default audio device the audio driver uses. This is driver dependent."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
      "Audio DSP plugin that processes audio before it's sent to the driver."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
      "Audio output samplerate."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
      "Opacity of all UI elements of the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
      "Scale of all UI elements of the overlay."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
      "オーバーレイを有効する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
      "Select an overlay from the file browser."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
      "The address of the host to connect to."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
      "The port of the host IP address. Can be either a TCP or UDP port."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
      "The password for connecting to the netplay host. Used only in host mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
      "ゲームのネットプレイを公開にアナウンスする。設定しないと、クライアントは手動で接続が必要です。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
      "The password for connecting to the netplay host with only spectator privileges. Used only in host mode."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
      "Whether to run netplay in a mode not requiring save states. If set to true, a very fast network is required, but no rewinding is performed, so there will be no netplay jitter."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
      "The frequency in frames with which netplay will verify that the host and client are in sync."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
      "When hosting, attempt to listen for connections from the public Internet, using UPnP or similar technologies to escape LANs."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
      "Enable stdin command interface."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
      "Enable mouse controls inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_POINTER_ENABLE,
      "Enable touch controls inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_THUMBNAILS,
      "Type of thumbnail to display."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
      "Shows current date and/or time inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
      "Shows current battery level inside the menu."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
      "Wrap-around to beginning and/or end if boundary of list is reached horizontally or vertically."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
      "Enables netplay in host (server) mode."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
      "Enables netplay in client mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
      "Disconnects an active Netplay connection.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
      "Scans a directory for compatible files and add them to the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_FILE,
      "Scans a compatible file and add it to the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
      "Uses a custom swap interval for Vsync. Set this to effectively halve monitor refresh rate."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
      "Sort save files in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
      "Sort save states in folders named after the core used."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
      "URL to core updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
      "URL to assets updater directory on the Libretro buildbot.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "After downloading, automatically extract archives that the downloads are contained inside."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
      "Scan for new rooms.")
MSG_HASH(MENU_ENUM_SUBLABEL_DELETE_ENTRY,
      "Remove this entry from the collection.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION,
      "View more information about the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_RUN,
      "Start the content.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
      "Adjusts filebrowser settings.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
      "Enable customized controls by default at startup."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
      "Enable customized configuration by default at startup."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
      "Enable customized core options by default at startup.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ENABLE,
      "Shows current core name inside menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
      "View databases.")
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
      "View previous searches.")
MSG_HASH(MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
      "Captures an image of the screen.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
      "Closes the current game. Any unsaved changes might be lost."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_STATE,
      "Load a saved state from the currently selected slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_STATE,
      "Save a state to the currently selected slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME,
      "Resume the currently running application and leave the Quick Menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME_CONTENT,
      "Resume the currently running application and leave the Quick Menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_STATE_SLOT,
      "Changes the currently selected state slot.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
      "If a state was loaded, content will go back to the state prior to loading.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
      "If a state was overwritten, it will roll back to the previous save state.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "Retro Achievements service. For more information, visit http://retroachievements.org"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
      "Manage currently configured accounts."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
      "Manages rewind settings.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESTART_CONTENT,
      "Restarts the content from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "Saves an override configuration file which will apply for all content loaded with this core. Will take precedence over the main configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "Saves an override configuration file which will apply for the current content only. Will take precedence over the main configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
      "Set up cheat codes for the currently running content.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
      "Set up shaders for the currently running content.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
      "Change the controls for the currently running content.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_OPTIONS,
      "Change the options for the currently running application.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
      "Show advanced settings for powerusers (hidden by default).")
MSG_HASH(MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
      "Perform tasks on a separate thread.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
      "Allow the user to remove entries from collections.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
      "Sets the System directory. Cores can query for this directory to load BIOSes, system-specific configs, etc.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
      "Sets start directory for the filebrowser.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DIR,
      "Usually set by developers who bundle libretro/RetroArch apps to point to assets."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
      "The place to store the wallpapers dynamically loaded by the menu depending on context.")
MSG_HASH(MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
      "To store thumbnail files."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
      "Sets start directory for menu configuration browser.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "The number of frames of input latency for netplay to use to hide network latency. This reduces jitter and makes netplay less CPU-intensive, at the expense of noticeable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "The range of frames of input latency that may be used to hide network latency. Reduces jitter and makes netplay less CPU-intensive, at the expense of unpredictable input lag.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
      "Cycle the current disk. If the disk is inserted, it will eject the disk. If the disk has not been inserted, it will be inserted. ")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_INDEX,
      "ディスクのインデックスを変更する。")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_OPTIONS,
      "ディスクのイメージ管理")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
      "ディスクイメージを追加する。")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
      "Makes sure the framerate is capped while inside the menu.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Select a different layout for the XMB interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_THEME,
      "Select a different theme for the icon. Changes will take effect after you restart the program.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
      "Enable drop shadows for all icons. This will have a minor performance hit.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
      "Select a different background color gradient theme.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
      "Modify the opacity of the background wallpaper.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
      "Select a different background color gradient theme.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
      "Select an animated background effect. Can be GPU-intensive depending on the effect. If performance is unsatisfactory, either turn this off or revert to a simpler effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_FONT,
      "メニューの使用するフォントを選択する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
      "メニューにイメージタブを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
      "メニューに音楽タブを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
      "メニューにビデオタブを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
      "メニューにネットプレイタブを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
      "メニューに設定タブを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
      "メニューに履歴タブを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
      "メニューにコンテンツをインポートするタブを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
      "メニューにスタートスクリーンを表示する。")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
      "Modify the opacity of the header graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
      "Modify the opacity of the footer graphic.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
      "The menu normally scales itself dynamically. If you want to set a specific scaling size instead, enable this.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
      "Set the custom scaling size here. NOTE: You have to enable 'DPI Override' for this scaling size to take effect.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
      "すべてのダウンロードしたファイルをこのフォルダに保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
      "すべてのコントローラリマップファイルをこのフォルダに保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
      "コアやアプリの検索するフォルダ。")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
      "コアやアプリの情報ファイルをこのフォルダに存在する。")
MSG_HASH(MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
      "If a joypad is plugged in, that joypad will be autoconfigured if a config file corresponding to it is present inside this directory.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
      "すべてのプレイリストをこのフォルダに保存する。")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
      "If set to a directory, content which is temporarily extracted (e.g. from archives) will be extracted to this directory."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
      "保存したクエリをこのフォルダに保存する。")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
      "データベースがこのフォルダに存在する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
      "This location is queried by default when menu interfaces try to look for loadable assets, etc."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
      "このフォルダにセーブファイルを保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
      "このフォルダに保存状態を保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
      "このフォルダにスクリーンショットを保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
      "オーバーレイがこのフォルダに存在する。")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
      "チートファイルがこのフォルダに存在する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
      "オーディオのDSPフィルターがこのフォルダに存在する。"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
      "CPUのビデオフィルターがこのフォルダに存在する。"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
      "GPUのビデオシェーダーがこのフォルダに存在する。")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
      "このフォルダに録画したビデオを保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
      "このフォルダに録画設定ファイルを保存する。")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
      "OSDの使用するフォントを選択する。")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
      "Changes to the shader configuration will take effect immediately. Use this if you changed the amount of shader passes, filtering, FBO scale, etc.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
      "Increase or decrease the amount of shader pipeline passes. You can bind a separate shader to each pipeline pass and configure its scale and filtering."
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
      "MITMサーバーを使用")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MITM_SERVER,
      "MITMサーバーの設置場所")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
      "中間者のサーバーにネットプレイ接続を転送する。ファイアウォールやNAT/UPnPが問題の時に便利。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
      "ミキサーに追加")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
      "ミキサーに追加")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
      "現在のコアで絞り込み")
MSG_HASH(
      MSG_AUDIO_MIXER_VOLUME,
      "グローバルのオーディオミキサー音量"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
      "Global audio mixer volume (in dB). 0 dB is normal volume, and no gain is applied."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
      "オーディオミキサー音量 (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
      "オーディオミキサーを消音"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
      "Mute/unmute mixer audio.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_ONLINE_UPDATER,
      "")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
      "オンラインアップデーターを表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_VIEWS_SETTINGS,
      "表示")
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_VIEWS_SETTINGS,
      "Show or hide elements on the menu screen."
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
      "コアのアップデーターを表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
      "Show/hide the ability to update cores (and core info files).")
MSG_HASH(MSG_PREPARING_FOR_CONTENT_SCAN,
      "コンテンツをスキャンするための準備中")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_DELETE,
      "コアを削除")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_DELETE,
      "コアをハードディスクから削除する。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
      "エントリーの名前を変更する")
MSG_HASH(MENU_ENUM_LABEL_RENAME_ENTRY,
      "Rename")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
      "フレームバッファーの透明性")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
      "Modify the opacity of the framebuffer.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
      "お気に入り")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
      "Content which you have added to 'Favorites' will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
      "音楽")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_MUSIC,
      "Music which has been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
      "画像")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_IMAGES,
      "Images which have been previously viewed will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
      "ビデオ")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_VIDEO,
      "Videos which have been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
      "メニューのアイコン")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
      "Enable/disable the menu icons shown at the lefthand side of the menu entries.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "設定タブを有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
      "設定タブを有効するパスワード")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
      "パスワードを入力してください")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
      "パスワードが正解")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
      "パスワードが違います")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Enables the Settings tab. A restart is required for the tab to appear.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Supplying a password when hiding the settings tab makes it possible to later restore it from the menu, by going to the Main Menu tab, selecting Enable Settings Tab and entering the password.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
      "Allow the user to rename entries in collections.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
      "エントリーの名前変更を許す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
      "「コアをロード」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
      "Show/hide the 'Load Core' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
      "「コンテンツをロード」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
      "Show/hide the 'Load Content' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
      "「情報」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
      "「設定ファイル」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
      "Show/hide the 'Configurations' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
      "「ヘルプ」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
      "Show/hide the 'Help' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
      "「終了」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
      "Show/hide the 'Quit RetroArch' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
      "「再起動」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
      "Show/hide the 'Reboot' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
      "クイックメニュー")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
      "Show or hide elements on the Quick Menu screen.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "「スクリーンショットを撮る」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Show/hide the 'Take Screenshot' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "「状態保存」と「保存状態をロード」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Show/hide the options for saving/loading state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "「保存状態のロードを前に戻す」と「状態の保存を前に戻す」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Show/hide the options for undoing save/load state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "「お気に入りに追加」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show/hide the 'Add to Favorites' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
      "「オプション」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
      "Show/hide the 'Options' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
      "「コントロール」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
      "Show/hide the 'Controls' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
      "「チート」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
      "Show/hide the 'Cheats' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
      "「シェーダー」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
      "Show/hide the 'Shaders' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "「コアの優先を保存」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Show/hide the 'Save Core Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "「ゲームの優先を保存」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Show/hide the 'Save Game Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
      "「情報」を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_ENABLE,
      "OSDメッセージ背景を有効")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_RED,
      "OSDメッセージ背景の赤色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_GREEN,
      "OSDメッセージ背景の緑色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_BLUE,
      "OSDメッセージ背景の青色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_BGCOLOR_OPACITY,
      "OSDメッセージ背景の不透明性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES,
      "お気に入りに追加")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_FAVORITES_PLAYLIST,
      "お気に入りに追加")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESET_CORE_ASSOCIATION,
      "コア関連をリセット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
      "キオスクモードを無効")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
      "Disables kiosk mode. A restart is required for the change to take full effect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
      "キオスクモードを有効")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
      "Protects the setup by hiding all configuration related settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
      "キオスクモードを無効するパスワードを設定")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
      "Supplying a password when enabling kiosk mode makes it possible to later disable it from the menu, by going to the Main Menu, selecting Disable Kiosk Mode and entering the password.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD,
      "パスワードを入力して下さい")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
      "パスワード正解。")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
      "パスワード不正解。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_RED,
      "OSDメッセージの赤色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_GREEN,
      "OSDメッセージの緑色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_COLOR_BLUE,
      "OSDメッセージの青色値")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAMECOUNT_SHOW,
      "フレームレート表示でフレーム数を表示")
MSG_HASH(MSG_CONFIG_OVERRIDE_LOADED,
      "優先ファイルをロードしました。")
MSG_HASH(MSG_GAME_REMAP_FILE_LOADED,
      "ゲームの優先ファイルをロードしました。")
MSG_HASH(MSG_CORE_REMAP_FILE_LOADED,
      "コアの優先ファイルをロードしました。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "自動的にコンテンツをプレイリストに追加")
MSG_HASH(MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Automatically scans loaded content so they appear inside playlists.")
MSG_HASH(MSG_SCANNING_OF_FILE_FINISHED,
      "Scanning of file finished")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_OPACITY,
      "ウィンドウの不透明性")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
      "オーディオリサンプラーの音質")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
      "Lower this value to favor performance/lower latency over audio quality, increase if you want better audio quality at the expense of performance/lower latency.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_WATCH_FOR_CHANGES,
      "シェーダーファイルの変更を監視")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_SHOW_DECORATIONS,
      "ウィンドウ枠を表示")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "統計を表示")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Show onscreen technical statistics.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Enable border filler")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Enable border filler thickness")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Enable background filler thickness")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION, "For 15 kHz CRT displays only. Attempts to use exact core/game resolution and refresh rate.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION, "CRT SwitchRes")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER, "When CRT SwitchRes is enabled, force ultrawide horizontal resolution to minimize mode switching.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER, "CRT Super Resolution")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Show Rewind Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Show/hide the Rewind options.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Show/hide the Latency options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Show Latency Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Show/hide the Overlay options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Show Overlay Settings")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "メニューのオーディオを有効")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Enable or disable menu sound.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "ミキサー設定")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "View and/or modify audio mixer settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_INFO,
      "詳細")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE,
      "ファイル(&F)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE_LOAD_CORE,
      "コアをロード(&L)...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE_UNLOAD_CORE,
      "コアをアンロード(&U)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_FILE_EXIT,
      "終了(&X)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_EDIT,
      "編集(&E)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_EDIT_SEARCH,
      "検索(&S)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW,
      "表示(&V)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_CLOSED_DOCKS,
      "閉じたドック")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS,
      "設定(&O)...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SAVE_DOCK_POSITIONS,
      "ドック配置を記憶:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SAVE_GEOMETRY,
      "ウィンドウ位置とサイズを記憶:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SAVE_LAST_TAB,
      "最後のコンテンツブラウザーのタブを記憶:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME,
      "テーマ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME_SYSTEM_DEFAULT,
      "<システムデフォルト>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME_DARK,
      "ダーク")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_THEME_CUSTOM,
      "カスタム...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_TITLE,
      "設定")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_NAME,
      "名前")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOAD_CUSTOM_CORE,
      "カスタムなコアをロード...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOAD_CORE,
      "コアをロード")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOADING_CORE,
      "コアをロード中...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE_VERSION,
      "バージョン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_PLAYLISTS,
      "プレイリスト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_FILE_BROWSER,
      "ファイルブラウザー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_FILE_BROWSER_TOP,
      "先頭")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_TAB_FILE_BROWSER_UP,
      "上へ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_DOCK_CONTENT_BROWSER,
      "コンテンツブラウザー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_BOXART,
      "ボックスアート")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_SCREENSHOT,
      "スクリーンショット")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_THUMBNAIL_TITLE_SCREEN,
      "タイトルスクリーン")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_ALL_PLAYLISTS,
      "すべてのプレイリスト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE,
      "コア")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE_INFO,
      "コア情報")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CORE_SELECTION_ASK,
      "<問い合わせる>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_INFORMATION,
      "情報")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_WARNING,
      "警告")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_ERROR,
      "エラー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_RESTART_TO_TAKE_EFFECT,
      "変更はRetroArchを再起動した後に反映されます。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_LOG,
      "ログ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_DONT_SHOW_AGAIN,
      "今後表示しない")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_STOP,
      "停止")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_ASSOCIATE_CORE,
      "コアに関連付ける")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_HIDDEN_PLAYLISTS,
      "隠したプレイリスト")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_HIDE,
      "隠す")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_HIGHLIGHT_COLOR,
      "ハイライトカラー")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CHOOSE,
      "選択(&C)...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_SELECT_COLOR,
      "色の選択")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_SELECT_THEME,
      "テーマの選択")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_CUSTOM_THEME,
      "カスタムなテーマ")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_PATH_IS_BLANK,
      "ファイルのパスは空きです。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_IS_EMPTY,
      "ファイルは空きです。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_READ_OPEN_FAILED,
      "ファイルを読み込みのために開けません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_FILE_DOES_NOT_EXIST,
      "ファイルは存在しません。")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QT_MENU_VIEW_OPTIONS_SUGGEST_LOADED_CORE_FIRST,
      "ロードしたコアを最初に優先する")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
